
Scenario API reference
======================

.. toctree::
   :maxdepth: 2
   :caption: Contents:

scenario.State
==============

.. automodule:: scenario.state


scenario.Context
================

.. automodule:: scenario.context


scenario.consistency_checker
============================

.. automodule:: scenario.consistency_checker


scenario.capture_events
=======================

.. automodule:: scenario.capture_events


Indices
=======

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
